/* Checkbook
 *
 * Version 1.1
 * 9/24/2020
 *
 * Functions declared:
 *
 * int exist(char file[]) - return 1 if file exists; 0 if it does not
 * int readfile(void) - display the contents of CBX file ('Checkbook' in user's home directory)
 * int appendfile(char string[]) - append a line of text to CBX file
 * int insertline(int ln, char string[]) - insert string before line number 'ln' in CBX file 
 * int rmline(int ln) - delete a line from CBX file
 * char * cfile(void) - returns full path to CBX file ('Checkbook' in user's home directory)
 * void new_file(void) - create a new CBX file; prompts before overwrite
 * double get_balance(void) - returns the balance of a CBX file
 * double dec_balance(double amount) - decrement the balance of a CBX file by 'amount'
 * double inc_balance(double amount) - increment the balance of a CBX file by 'amount'
 * void withdraw(char num[8], char date[10], char desc[16], double amount) - add a withdrawal (payment) transaction to CBX file
 * void deposit(char num[8], char date[10], char desc[16], double amount) - add a deposit transaction to CBX file
 * char * tab(int len) - returns proper tab formatting for transactions; used by withdraw() and deposit()
 * char * ttab(int len) - modified version of tab(); also used by withdraw() and deposit()
 *
 * checkbook.h
 */

#ifndef _CHECKBOOK_H
#define _CHECKBOOK_H 1

#define CFILE		"Checkbook"
#define MAIN_HEADER	"CHECKBOOK1.1 / %s\n\nBalance:\n$"
#define HEADER		"CHECKBOOK1.1 / %s\n\nBalance:\n$%.2lf\n\nNum\tDate\tDescription\t\t\t+/-\t\t\tBalance\n-------------------------------------------------------------------------------\n\n"

#define CFILE_MISSING	"%s not found. Run with '-n' option to create a new file.\n"

#define HELP_TEXT "cbx -h\tDisplay this help\ncbx -n\tCreate a new checkbook file ('Checkbook' in user's home directory)\ncbx -b\tDisplay account balance\ncbx -v\tDisplay checkbook file\n\ncbx -w <num> <date> <desc> <amount>\tAdd a withdrawal (payment) transaction\ncbx -d <num> <date> <desc> <amount>\tAdd a deposit transaction\n\t<num>    - check number (or any other short notation, e.g. 'DC', 'DEP')\n\t<date>   - date of transaction (e.g. 9-5)\n\t<desc>   - transaction description (up to 15 characters)\n\t           enclose in single-quotes ('') if using space characters in <desc>\n\t<amount> - dollar amount (without dollar sign); may be a decimal or an integer\n"

#define USER (getenv("USER"))
#define HOME (getenv("HOME"))

double balance, _balance, nbal, inbal, xbal;

int exist(char file[]);

int readfile(void);

int appendfile(char string[]);

int insertline(int ln, char string[]);

int rmline(int ln);

char * cfile(void);

void new_file(void);

double get_balance(void);

double dec_balance(double amount);

double inc_balance(double amount);

void withdraw(char num[8], char date[10], char desc[16], double amount);

void deposit(char num[8], char date[10], char desc[16], double amount);

char * tab(int len);

char * ttab(int len);

#endif /* _CHECKBOOK_H */
